import argparse
from typing import Dict, Union


def parser() -> Dict[str, Union[str, bool]]:
    """
    Parse command line arguments and return pair from
    path and selection (true or false)
    """
    parser = argparse.ArgumentParser()
    parser.add_argument("-d", "--directory", type=str,
                        help="specify path to catalog, where screenshots will be stored")
    parser.add_argument("-f", "--file", type=str,
                        help="specify path to file where image will be stored")
    parser.add_argument("-s", "--selection", action="store_true",
                        help="use this flag if you want to select area")
    args = parser.parse_args()

    return {"file": args.file,
            "dir": args.directory,
            "selection": args.selection}



import subprocess
import sys
from typing import List


def screenshot(selection: bool) -> bytes:
    """
    Get boolean selection,
    take a screenshot and return it as bytes
    """
    cmd = ["maim"]
    if selection:
        cmd.append("-s")

    try:
        img = subprocess.run(cmd, stdout=subprocess.PIPE).stdout
    except FileNotFoundError:
        sys.stderr.write("We can't find {} in your $PATH\n".format(cmd[0]))
        sys.exit(1)

    return img


def to_clipboard(img: bytes) -> None:
    """
    Take image from arguments (bytes returned from function screenshot)
    and place it to clipboard using xclip
    """
    cmd = ["xclip", "-selection", "clipboard", "-t", "image/png"]
    try:
        subprocess.run(cmd, input=img)
    except FileNotFoundError:
        sys.stderr.write("We can't find {} in your $PATH\n".format(cmd[0]))
        sys.exit(1)


def to_save(img: bytes, path: str) -> None:
    """
    Save file (bytes returned from screenshot) to given path
    """
    with open(path, mode='wb') as temp:
        temp.write(img)



from os import listdir
from datetime import datetime


def save_path(save_dir: str, ext: str) -> str:
    t = datetime.now()
    save_file = "{y}|{mth}|{d}_{h}:{mn}:{s}".format(
        y=t.year,
        mth=t.month,
        d=t.day,
        h=t.hour,
        mn=t.minute,
        s=t.second,
    )
    
    # check if file won't have duplicates
    ls = listdir(save_dir)
    while (save_file + ext) in ls:
        save_file += "_1"
    return save_file + ext



from .core import *
from .parse import parser
from .save import save_path

def main():
    args = parser()

    selection = args["selection"]
    img = screenshot(selection)

    to_clipboard(img)
    print("Screenshot saved to clipboard")

    if args["file"]:
        path = args["file"]
    elif args["dir"]:
        ext = ".png"
        path = save_path(args["dir"], ext)
    else:
        path = ''

    if path:
        to_save(img, path)
        print("File saved to {}".format(path))

if __name__ == "__main__":
    main()




from setuptools import setup
from os import path


here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='lumes',
    version='0.0.3a0',
    description='A simple wraper for screenshot',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/juliancoffee/lumes-py/',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Topic :: Utilities',
        'Operating System :: POSIX :: Linux',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
    python_requires='>=3, <4',
    keywords='screenshot',
    packages=['lumes'],
    entry_points={
        'console_scripts': [
            'lumes=lumes.__main__:main',
        ],
    },
    project_urls={
        'Bug Reports': 'https://github.com/juliancoffee/lumes-py/issues',
        'Source': 'https://github.com/juliancoffee/lumes-py/',
    },
)
